@@ -22,6 +22,7 @@ from fx_bin.errors import ReplaceError, IOError as FxIOError
 @dataclass(frozen=True)
 class ReplaceContext:
     """Context for replacement operations."""
+
     search_text: str
     replace_text: str
     create_backup: bool = True
@@ -31,6 +32,7 @@ class ReplaceContext:
 @dataclass(frozen=True)
 class FileBackup:
     """Represents a file backup."""
+
     original_path: str
     backup_path: str
     original_mode: int
@@ -48,11 +50,7 @@ def validate_file_access(filename: str) -> Result[str, ReplaceError]:
             return Failure(ReplaceError(f"File is not writable: {filename}"))
 
         # Follow symlinks to get real path
-        real_path = (
-            os.path.realpath(filename)
-            if os.path.islink(filename)
-            else filename
-        )
+        real_path = os.path.realpath(filename) if os.path.islink(filename) else filename
 
         return Success(real_path)
     except Exception as e:
@@ -73,34 +71,31 @@ def create_backup(filename: str) -> IOResult[FileBackup, FxIOError]:
         # Copy file with metadata
         shutil.copy2(filename, backup_path)
 
-        return IOResult.from_value(FileBackup(
-            original_path=filename,
-            backup_path=backup_path,
-            original_mode=original_mode
-        ))
-    except Exception as e:
-        return IOResult.from_failure(
-            FxIOError(f"Failed to create backup: {e}")
+        return IOResult.from_value(
+            FileBackup(
+                original_path=filename,
+                backup_path=backup_path,
+                original_mode=original_mode,
+            )
         )
+    except Exception as e:
+        return IOResult.from_failure(FxIOError(f"Failed to create backup: {e}"))
 
 
 @impure_safe
 def perform_replacement(
-    context: ReplaceContext,
-    backup: FileBackup
+    context: ReplaceContext, backup: FileBackup
 ) -> IOResult[str, FxIOError]:
     """Perform the actual text replacement."""
     try:
         # Create temporary file in same directory for atomic move
         temp_dir = os.path.dirname(os.path.abspath(backup.original_path))
-        fd, tmp_path = tempfile.mkstemp(dir=temp_dir, prefix='.tmp_replace_')
+        fd, tmp_path = tempfile.mkstemp(dir=temp_dir, prefix=".tmp_replace_")
 
         try:
             # Perform replacement
-            with os.fdopen(fd, 'w', encoding='utf-8') as tmp_file:
-                with open(
-                    backup.original_path, 'r', encoding='utf-8'
-                ) as original_file:
+            with os.fdopen(fd, "w", encoding="utf-8") as tmp_file:
+                with open(backup.original_path, "r", encoding="utf-8") as original_file:
                     for line in original_file:
                         modified_line = line.replace(
                             context.search_text, context.replace_text
@@ -112,7 +107,7 @@ def perform_replacement(
                 os.chmod(tmp_path, stat.S_IMODE(backup.original_mode))
 
             # Atomic replacement
-            if os.name == 'nt':  # Windows
+            if os.name == "nt":  # Windows
                 # Windows doesn't support atomic rename to existing file
                 os.unlink(backup.original_path)
                 os.rename(tmp_path, backup.original_path)
@@ -128,9 +123,7 @@ def perform_replacement(
             raise e
 
     except Exception as e:
-        return IOResult.from_failure(
-            FxIOError(f"Failed to perform replacement: {e}")
-        )
+        return IOResult.from_failure(FxIOError(f"Failed to perform replacement: {e}"))
 
 
 @impure_safe
@@ -157,15 +150,11 @@ def restore_from_backup(backup: FileBackup) -> IOResult[None, FxIOError]:
             os.chmod(backup.original_path, stat.S_IMODE(backup.original_mode))
         return IOResult.from_value(None)
     except Exception as e:
-        return IOResult.from_failure(
-            FxIOError(f"Failed to restore from backup: {e}")
-        )
+        return IOResult.from_failure(FxIOError(f"Failed to restore from backup: {e}"))
 
 
 def work_functional(
-    search_text: str,
-    replace_text: str,
-    filename: str
+    search_text: str, replace_text: str, filename: str
 ) -> IOResult[None, ReplaceError]:
     """
     Replace text in a file with functional error handling.
@@ -186,7 +175,7 @@ def work_functional(
 
     # Perform replacement with automatic restore on failure
     def replace_with_restore(
-        backup: FileBackup
+        backup: FileBackup,
     ) -> IOResult[None, ReplaceError]:
         replacement_result = perform_replacement(context, backup)
 
@@ -210,9 +199,7 @@ def work_functional(
 
 
 def work_batch_functional(
-    search_text: str,
-    replace_text: str,
-    filenames: List[str]
+    search_text: str, replace_text: str, filenames: List[str]
 ) -> IOResult[List[Result[str, ReplaceError]], ReplaceError]:
     """
     Replace text in multiple files with transaction-like behavior.
@@ -292,9 +279,7 @@ def main(search_text: str, replace_text: str, filenames: tuple) -> None:
 
     if len(filenames) == 1:
         # Single file replacement
-        result = work_functional(
-            search_text, replace_text, filenames[0]
-        ).run()
+        result = work_functional(search_text, replace_text, filenames[0]).run()
 
         if isinstance(result, Failure):
             L.error(f"Replacement failed: {result.failure()}")
@@ -303,20 +288,15 @@ def main(search_text: str, replace_text: str, filenames: tuple) -> None:
             L.info(f"Successfully replaced in {filenames[0]}")
     else:
         # Batch replacement with transaction semantics
-        result = work_batch_functional(
-            search_text, replace_text, list(filenames)
-        ).run()
+        result = work_batch_functional(search_text, replace_text, list(filenames)).run()
 
         if isinstance(result, Failure):
             L.error(f"Batch replacement failed: {result.failure()}")
             raise SystemExit(1)
         else:
-            success_count = sum(
-                1 for r in result.unwrap() if isinstance(r, Success)
-            )
+            success_count = sum(1 for r in result.unwrap() if isinstance(r, Success))
             L.info(
-                f"Successfully replaced in {success_count}/"
-                f"{len(filenames)} files"
+                f"Successfully replaced in {success_count}/" f"{len(filenames)} files"
             )
 
 
